@@ -192,7 +192,7 @@ class DSMRReader():
 
                 # print(f'{entity.name} == {value} {entity.unit or ""}')
 
-                data[entity.name] = f'{value} {entity.unit or ""}'
+                data[entity.name] = f'{value} {entity.unit or ""}'.strip()
 
             print(json.dumps(data, indent=2))
 
